@@ -24,7 +24,7 @@ class TwoImageTransformation:
 		self.construct_class = construct_class
 
 	def __call__(self, image1, image2):
-		if image == None:
+		if image1 == None or image2 == None:
 			raise ValueError("You have improperly called the image constructor.")
 		else:
 			if self.construct_class == None:
